import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ClusterRoleConfig extends TerraformMetaArguments {
    /** metadata block */
    readonly metadata: ClusterRoleMetadata[];
    /** rule block */
    readonly rule: ClusterRoleRule[];
}
export interface ClusterRoleMetadata {
    /** An unstructured key value map stored with the clusterRole that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations */
    readonly annotations?: {
        [key: string]: string;
    };
    /** Map of string keys and values that can be used to organize and categorize (scope and select) the clusterRole. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the clusterRole, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
}
export interface ClusterRoleRule {
    /** APIGroups is the name of the APIGroup that contains the resources. If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed. */
    readonly apiGroups?: string[];
    /** NonResourceURLs is a set of partial urls that a user should have access to. *s are allowed, but only as the full, final step in the path Since non-resource URLs are not namespaced, this field is only applicable for ClusterRoles referenced from a ClusterRoleBinding. Rules can either apply to API resources (such as "pods" or "secrets") or non-resource URL paths (such as "/api"), but not both. */
    readonly nonResourceUrls?: string[];
    /** ResourceNames is an optional white list of names that the rule applies to. An empty set means that everything is allowed. */
    readonly resourceNames?: string[];
    /** Resources is a list of resources this rule applies to. ResourceAll represents all resources. */
    readonly resources?: string[];
    /** Verbs is a list of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule. VerbAll represents all kinds. */
    readonly verbs: string[];
}
export declare class ClusterRole extends TerraformResource {
    constructor(scope: Construct, id: string, config: ClusterRoleConfig);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _metadata;
    get metadata(): ClusterRoleMetadata[];
    set metadata(value: ClusterRoleMetadata[]);
    private _rule;
    get rule(): ClusterRoleRule[];
    set rule(value: ClusterRoleRule[]);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
